@@ -1,8 +1,10 @@
 import subprocess
 import requests
+from requests.auth import HTTPDigestAuth
 import json
-import base64
-import struct
+import getpass
+from OntimDevTool import auth_server
+from OntimDevTool import secure_access
 
 def get_device_id():
     ret = subprocess.run(['fastboot', 'oem', 'get_device_id'], capture_output=True)
@@ -10,13 +12,24 @@ def get_device_id():
     print(f"Get device id: {device_id}")
     return device_id
 
+
 def sign(project, data):
     print("Waiting for sign from anth server...")
+
     header = {"Content-Type": "application/json"}
+
+    if (secure_access):
+        username = input("Please input username: ")
+        password = getpass.getpass("Please input password: ")
+        auth = HTTPDigestAuth(username, password)
+        ret = requests.get(auth_server + "Token/", auth = auth)
+        token = json.loads(ret.content.decode('ascii'))['token']
+        header["Authorization"] = "Bearer "+ token
+
     payload = {"project": project, "data": data}
-    ret = requests.post("http://192.168.12.81:8888/no_auth/SignDIAG/", headers = header, data = json.dumps(payload))
+    ret = requests.post(auth_server + "SignDIAG/", headers = header, data = json.dumps(payload))
     sign_resp = json.loads(ret.content.decode('ascii'))['data']
-    # print(f"sign diag success, resp = {sign_resp}")
+    #print(f"sign diag success, resp = {sign_resp}")
     return sign_resp
 
 def set_diag_port(data):
@@ -27,7 +40,7 @@ def set_diag_port(data):
             tmp_file.write(data)
 
         ret = subprocess.run(['fastboot', 'flash', 'diag', dia_tmp_file], capture_output=True)
-        if ret.stderr.decode('ascii').split('\n')[-1].find("Finished. Total time:"):
+        if ret.stderr.decode('ascii').find("Finished. Total time:") != -1:
             return True
         else:
             print(ret.stderr.decode('ascii'))
@@ -35,7 +48,7 @@ def set_diag_port(data):
     else:
         # close diag
         ret = subprocess.run(['fastboot', 'oem', 'diag_lock'], capture_output=True)
-        if ret.stderr.decode('ascii').split('\n')[-1].find("Finished. Total time:"):
+        if ret.stderr.decode('ascii').find("Finished. Total time:") != -1:
             return True
         else:
             print(ret.stderr.decode('ascii'))
